<?php

namespace Rokt\Plugin\Ecommerce\Api;

defined( 'ABSPATH' ) || exit;

use Rokt\Plugin\Ecommerce\Includes\Constants;
use Rokt\Plugin\Ecommerce\Includes\Helper;
use Rokt\Plugin\Ecommerce\Plugin;

class Accounts extends \WP_REST_Controller {
	public $plugin;

	const SLUG = 'plug';
	const PATH = 'accounts';

	public function __construct( $plugin ) {
		$this->plugin = $plugin;
	}

	public function register_routes() {
		register_rest_route(
			Init::$base_namespace,
			'/' . self::PATH,
			array(
				array(
					'methods'             => \WP_REST_Server::CREATABLE,
					'callback'            => array( $this, 'save_account' ),
					'permission_callback' => array( $this, 'check_permissions' ),
				),
			)
		);

		register_rest_route(
			Init::$base_namespace,
			'/' . self::PATH . '/placement-type',
			array(
				array(
					'methods'             => \WP_REST_Server::CREATABLE,
					'callback'            => array( $this, 'set_placement_type' ),
					'permission_callback' => array( $this, 'check_permissions' ),
				),
			)
		);
	}

	public function save_account( \WP_REST_Request $request ) {
		// TODO: Validate the request body.
		$request_body = $request->get_body();
		$is_updated   = Helper::update_option( Constants::ACCOUNT_DETAIL_KEY, $request_body );

		return new \WP_REST_Response(
			array(
				'data' => array(
					'isUpdated' => $is_updated,
				),
			)
		);
	}

	public function set_placement_type( \WP_REST_Request $request) {
		$placement      = json_decode( $request->get_body(), true );
		$placement_type = $placement['type'];
		if ( !in_array( $placement_type , Constants::PLACEMENT_TYPES, true) ) {
			return new \WP_REST_Response(
				array(
					'error' => 'Only accepts value of [' . implode( ',', Constants::PLACEMENT_TYPES) . ']',
				),
				400
			);
		}

		Helper::update_option( Constants::PLACEMENT_TYPE_KEY, $placement_type );

		return new \WP_REST_Response(
			array(
				'data' => $placement,
			)
		);
	}

	public function check_permissions() {
		return current_user_can( Plugin::$required_capability );
	}
}
