<?php

namespace Rokt\Plugin\Ecommerce\Api;

defined( 'ABSPATH' ) || exit;

use Rokt\Plugin\Ecommerce\Includes\Constants;
use Rokt\Plugin\Ecommerce\Includes\Helper;
use Rokt\Plugin\Ecommerce\Plugin;
use WP_Http;

class RoktProxy extends \WP_REST_Controller {
	private $http;
	public $plugin;

	const SLUG                   = 'plug';
	const PATH                   = 'rokt-proxy';
	const DEFAULT_REST_API_QUERY = 'rest_route';

	public function __construct( $plugin ) {
		$this->http   = new WP_Http();
		$this->plugin = $plugin;
	}

	public function register_routes() {
		register_rest_route(
			Init::$base_namespace,
			'/' . self::PATH . '/(?P<' . self::SLUG . '>\S+)',
			array(
				array(
					'methods'             => \WP_REST_Server::ALLMETHODS,
					'callback'            => array( $this, 'request' ),
					'permission_callback' => array( $this, 'check_permissions' ),
				),
			)
		);
	}

	public function request( \WP_REST_Request $request ) {
		$request_slug = $request->get_url_params()[ self::SLUG ];
		$url          = add_query_arg(
			$this->get_query_params( $request ),
			$this->plugin->config['rokt_api_endpoint'] . '/' . $request_slug
		);

		if ( empty( $request_slug ) ) {
			return new \WP_Error( 'EMPTY_SLUG', 'Missing URL params.', null );
		}

		$args = array(
			'method'  => $request->get_method(),
			'headers' => $this->get_headers(),
			'timeout' => 30,
			'body'    => $request->get_body(),
		);

		$response = $this->http->request( $url, $args );

		$response_code    = wp_remote_retrieve_response_code( $response );
		$response_message = wp_remote_retrieve_response_message( $response );
		$response_body    = json_decode( wp_remote_retrieve_body( $response ), true );

		if ( is_wp_error( $response ) ) {
			return new \WP_Error( $response_code, $response_message, $response_body );
		}

		return new \WP_REST_Response( $response_body, $response_code );
	}

	private function get_query_params( \WP_REST_Request $request ) {
		$query = $request->get_query_params();
		if ( isset( $query[ self::DEFAULT_REST_API_QUERY ] ) ) {
			unset( $query[ self::DEFAULT_REST_API_QUERY ] );
		}
		return $query;
	}

	private function get_headers() {
		return array(
			'x-api-key'        => Helper::get_option( Constants::API_SECRET_KEY ),
			'x-client-version' => Helper::get_plugin_version(),
			'x-client-name'    => ROKT_ECOMMERCE_CLIENT_NAME,
			'content-type'     => 'application/json',
		);
	}

	public function check_permissions() {
		return current_user_can( Plugin::$required_capability );
	}
}
