<?php

namespace Rokt\Plugin\Ecommerce\Includes;

defined( 'ABSPATH' ) || exit;


use Rokt\Plugin\Ecommerce\Plugin;
use Rokt\Plugin\Ecommerce\Includes\Constants;

class Helper {

	public static function get_option( $key, $default = false ) {
		return get_option( self::get_namespaced_key( $key ), $default );
	}

	public static function update_option( $key, $value ) {
		return update_option( self::get_namespaced_key( $key ), $value );
	}

	public static function delete_option( $key ) {
		return delete_option( self::get_namespaced_key( $key ) );
	}

	public static function get_namespaced_key( $key ) {
		return Plugin::$plugin_name . '-' . $key;
	}

	public static function check_woocommerce_plugin_status() {
		// if you are using a custom folder name other than woocommerce just define the constant to TRUE.
		if ( defined( 'RUNNING_CUSTOM_WOOCOMMERCE' ) && RUNNING_CUSTOM_WOOCOMMERCE === true ) {
			return true;
		}
		// it the plugin is active, we're good.
		if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
			return true;
		}
		if ( ! is_multisite() ) {
			return false;
		}
		$plugins = get_site_option( 'active_sitewide_plugins' );
		return isset( $plugins['woocommerce/woocommerce.php'] );
	}

	public static function get_rokt_account() {
		$account_detail_json = self::get_option( Constants::ACCOUNT_DETAIL_KEY, '' );
		return json_decode( $account_detail_json, true );
	}

	public static function get_plugin_version() {
		static $plugin_version = null;
		if ( null === $plugin_version ) {
			// Get main plugin file header version.
			$plugin_data    = get_file_data( ROKT_ECOMMERCE_PLUGIN_FILE, array( 'Version' => 'Version' ) );
			$plugin_version = $plugin_data['Version'];
		}
		return $plugin_version;
	}

	public static function get_account_name ( $user ) {
		$first_name   = $user->first_name;
		$last_name    = $user->last_name;
		$display_name = $user->display_name;

		if (empty($first_name) && empty($last_name)) {
			return array(
				'firstName' => $display_name,
				'lastName'  => $display_name,
				'fullName'  => $display_name,
			);
		}

		if (!empty($first_name) && empty($last_name)) {
		  return array(
			'firstName'    => $first_name,
			'lastName'     => $first_name,
			'fullName'     => $first_name,
			);
		}

		if (empty($first_name) && !empty($last_name)) {
		  return array(
			'firstName' => $last_name,
			'lastName'  => $last_name,
			'fullName'  => $last_name,
				  );
		}

		return array(
			'firstName' => $first_name,
			'lastName'  => $last_name,
			'fullName'  => $first_name . ' ' . $last_name,
		);

	}
}
