<?php

namespace Rokt\Plugin\Ecommerce\Includes;

use WP_Http;

defined( 'ABSPATH' ) || exit;

class RoktApiClient {
	private $http_client;
	private $config;

	public function __construct( $config) {
		$this->config      = $config;
		$this->http_client = new WP_Http();
	}

	public function request( $url_path, $args = array()) {
		if (empty($args['headers'])) {
			$args['headers'] = array();
		}

		$args['headers'] = array_merge( $args['headers'] , $this->get_headers() );

		if (empty($args['method'])) {
			$args['method'] = \WP_REST_Server::READABLE;
		}

		$response = $this->http_client->request($this->config['rokt_api_endpoint'] . $url_path, $args);
		return json_decode( wp_remote_retrieve_body( $response ), true );
	}

	public function logError( $request_url, $api_response_message) {
		try {
			$this->request('/v1/log-error', array(
				'method' => \WP_REST_Server::CREATABLE,
				'body' => wp_json_encode(array(
					'message' => 'API request failed',
					'source' => get_site_url(),
					'metadata' => array(
						'request' => array(
							'url' => strpos($request_url, 'http') === 0  ? $request_url : $this->config['rokt_api_endpoint'] . $request_url,
						),
						'response' => array(
							'message' => $api_response_message
						)
					)
				)
			)));
		} catch (\Exception $e) { //phpcs:ignore

		}
	}

	private function get_headers() {
		return array(
			'x-api-key'        => Helper::get_option( Constants::API_SECRET_KEY ),
			'x-client-version' => Helper::get_plugin_version(),
			'x-client-name'    => ROKT_ECOMMERCE_CLIENT_NAME,
			'content-type'     => 'application/json; charset=utf-8',
		);
	}
}
