<?php

namespace Rokt\Plugin\Ecommerce;

defined( 'ABSPATH' ) || exit;

use Rokt\Plugin\Ecommerce\Admin\Admin as PluginAdmin;
use Rokt\Plugin\Ecommerce\StoreFront\StoreFront;
use Rokt\Plugin\Ecommerce\Api\Init as InitRestApi;
use Rokt\Plugin\Ecommerce\Includes\Loader;

class Plugin {
	public static $plugin_name         = 'rokt-ecommerce';
	public static $required_capability = 'manage_woocommerce';

	public $config;
	protected $loader;

	public function __construct( $config = array() ) {
		$this->config = $config;
		$this->define_constants();
		$this->load_dependencies();
		$this->define_admin_hooks();
		$this->define_public_hooks();
	}

	protected function define_constants() {
		$this->define( 'ROKT_ECOMMERCE_ABSPATH', dirname( __DIR__ ) );
		$this->define( 'ROKT_ECOMMERCE_PLUGIN_FILE', ROKT_ECOMMERCE_ABSPATH . DIRECTORY_SEPARATOR . 'rokt-ecommerce.php' );
		$this->define( 'ROKT_ECOMMERCE_CLIENT_NAME', 'Rokt Ecommerce on WooCommerce' );
	}

	public function run() {
		$this->loader->run();
	}

	private function load_dependencies() {
		$this->loader = new Loader();

		$rest_api = new InitRestApi( $this );
		$this->loader->add_action( 'rest_api_init', $rest_api, 'register_routes' );
		$this->loader->add_action( 'allowed_redirect_hosts', $rest_api, 'allowed_redirect_hosts' );
	}

	private function define_admin_hooks() {
		$plugin_admin = new PluginAdmin( $this );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );

		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_admin_menu', 99 );

		$this->loader->add_action( 'admin_notices', $plugin_admin, 'inject_before_notices', -9999 );
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'get_started_notice' );
		$this->loader->add_action( 'admin_notices', $plugin_admin, 'inject_after_notices', PHP_INT_MAX );

		$plugin_admin->listen_shop_update();
	}

	private function define_public_hooks() {
		$plugin_public = new StoreFront( $this );

		$this->loader->add_action( 'woocommerce_thankyou', $plugin_public, 'inject_rokt_sdk_script', 10, 1 );
		$this->loader->add_action( 'woocommerce_after_checkout_form', $plugin_public, 'inject_rokt_preparative_iframe', 10 );

		$plugin_public->inject_embedded_placement_placeholders();
	}

	protected function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}
}
