<?php

namespace Rokt\Plugin\Ecommerce\StoreFront;

defined( 'ABSPATH' ) || exit;

use Rokt\Plugin\Ecommerce\Includes\Constants;
use Rokt\Plugin\Ecommerce\Includes\Helper;

class StoreFront {
	const ROKT_ACCOUNT = 'accountId';
	const TAG_ID       = 'tagId';

	public $plugin;
	private $rokt_account;


	public function __construct( $plugin ) {
		$this->plugin       = $plugin;
		$this->rokt_account = Helper::get_rokt_account();
	}

	private function get_order_attributes( $order_id ) {
		$order = \wc_get_order( $order_id );

		if ( empty( $order ) ) {
			return array();
		}

		$user_id  = get_post_meta( $order_id, '_customer_user', true );
		$customer = new \WC_Customer( $user_id );

		return array(
			'email'           => empty( $order->get_billing_email() ) ? $customer->get_email() : $order->get_billing_email(),

			'firstname'       => empty( $order->get_billing_first_name() ) ? $customer->get_first_name() : $order->get_billing_first_name(),
			'lastname'        => empty( $order->get_billing_last_name() ) ? $customer->get_last_name() : $order->get_billing_last_name(),

			'mobile'          => $order->get_billing_phone(),

			'amount'          => $order->get_total(),
			'currency'        => $order->get_currency(),
			'confirmationref' => $order->get_order_key(),
			'paymenttype'     => $order->get_payment_method(),
			'shippingtype'    => $order->get_shipping_method(),

			'address1'        => $order->get_billing_address_1(),
			'address2'        => $order->get_billing_address_2(),
			'zipcode'         => $order->get_billing_postcode(),
			'city'            => $order->get_billing_city(),
			'state'           => $order->get_billing_state(),
			'country'         => $order->get_billing_country(),
		);
	}

	public function inject_rokt_sdk_script( $order_id ) {
		if ( $this->is_invalid_account() ) {
			return;
		}

		$rokt_tag_id     = $this->rokt_account[ self::ROKT_ACCOUNT ] . '_' . $this->rokt_account[ self::TAG_ID ];
		$rokt_attributes = $this->get_order_attributes( $order_id );
		$rokt_sdk_script = $this->plugin->config['rokt_sdk_script'];

		require_once plugin_dir_path( __FILE__ ) . 'partials/rokt-sdk-script.php';
	}


	public function inject_embedded_placement_placeholders() {
		if ( $this->is_invalid_account() ) {
			return;
		}

		$placement_type = Helper::get_option( Constants::PLACEMENT_TYPE_KEY );
		if ( Constants::EMBEDDED_PLACEMENT_TYPE !== $placement_type ) {
			return;
		}

		\add_action( 'woocommerce_before_thankyou', function () {
			echo ( '<div id="rokt_container_above_order_received"></div>' );
		}, 10 );

		\add_action( 'woocommerce_order_details_before_order_table', function () {
			echo ( '<div id="rokt_container_below_order_received"></div>' );
		}, 10 );

		\add_action( 'woocommerce_after_order_details', function () {
			echo ( '<div id="rokt_container_below_order_details"></div>' );
		}, 10 );
	}

	public function inject_rokt_preparative_iframe() {
		if ( $this->is_invalid_account() ) {
			return;
		}

		$rokt_preparative_iframe_src = $this->plugin->config['rokt_preparative_iframe_src'];

		require_once plugin_dir_path( __FILE__ ) . 'partials/rokt-preparative-iframe.php';
	}

	private function is_invalid_account() {
		return empty( $this->rokt_account ) ||
		empty( $this->rokt_account[ self::ROKT_ACCOUNT ] ) ||
		empty( $this->rokt_account[ self::TAG_ID ] );
	}
}
