<?php

namespace Rokt\Plugin\Ecommerce;

use Rokt\Plugin\Ecommerce\Includes\Constants;
use Rokt\Plugin\Ecommerce\Includes\Helper;
use Rokt\Plugin\Ecommerce\Includes\RoktApiClient;

// If uninstall not called from WordPress, then exit.
if (! defined('WP_UNINSTALL_PLUGIN')) {
	exit;
}

if (is_readable(__DIR__ . '/vendor/autoload.php')) {
	require __DIR__ . '/vendor/autoload.php';
}

class UninstallPlugin {

	public $config;
	private $rokt_api_client;

	public function __construct( $config = array()) {
		$this->config          = $config;
		$this->rokt_api_client = new RoktApiClient($config);
	}

	public function run() {
		$this->call_un_installation_endpoint();
		$this->remove_plugin_data();
	}

	private function remove_plugin_data() {
		Helper::delete_option(Constants::ACCOUNT_DETAIL_KEY);
		Helper::delete_option(Constants::API_SECRET_KEY);
		Helper::delete_option(Constants::PLACEMENT_TYPE_KEY);
	}

	private function call_un_installation_endpoint() {
		$uninstall_endpoint = '/v1/appinstallations';
		try {
			$this->rokt_api_client->request($uninstall_endpoint, array('method' => \WP_REST_Server::DELETABLE));
		} catch (\Exception $e) {
			// phpcs:disable WordPress.PHP.DevelopmentFunctions
			error_log('Rokt Ecommerce: Failed to clean up the plugin data. Allowing uninstall anyway.');
			// phpcs:enable

			$this->rokt_api_client->logError( $uninstall_endpoint,
						$e->getMessage());

		}
	}
}


$config = require __DIR__ . '/config.php';

if (is_readable(__DIR__ . '/config.local.php')) {
	$local_config = require __DIR__ . '/config.local.php';
	$config       = array_merge($config, $local_config);
}

$uninstall_plugin = new UninstallPlugin($config);
$uninstall_plugin->run();
